@@ -81,11 +81,13 @@ class DriftChecker(abc.ABC):
 
         self.cat_features = (df_left_data
                              .select_dtypes(include=['category', 'object'])
-                             .columns)
+                             .columns
+                             .tolist())
 
         self.num_features = (df_left_data
                              .select_dtypes(include='number')
-                             .columns)
+                             .columns
+                             .tolist())
 
         self.ml_discriminate_model = None
         self.auc_discriminate_model = None
@@ -277,7 +279,7 @@ class DriftChecker(abc.ABC):
             )
 
         # Only left data scores are needed
-        y_score_left = df_predictions_all_folds.iloc[self.df_left_data.index]
+        y_score_left = df_predictions_all_folds.loc[self.df_left_data.index]
 
         # Reset verbose and minimal values
         self.minimal = actual_self_minimal
@@ -400,12 +402,12 @@ class DataDriftChecker(DriftChecker):
         )
 
         empty_num_features_and_cat_features_pvalues_filled = (
-                not self.num_features.tolist()
+                not self.num_features
                 and self.dict_each_column_pvalues_categorical
         )
 
         empty_cat_features_and_num_features_pvalues_filled = (
-                not self.cat_features.tolist()
+                not self.cat_features
                 and self.dict_each_column_pvalues_numerical
         )
 
